==> members-facade-1.0.2-20190814.130751-231-sources.jar: com/bizvane/members/facade/service/card/request/IntegralChangeRequestModel.java <==
package com.bizvane.members.facade.service.card.request;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/17.
 */
@Data
@EqualsAndHashCode
public class IntegralChangeRequestModel {

    @ApiModelProperty(name = "sysCompanyId", value = "公司id")
    private Long sysCompanyId;

    @ApiModelProperty(name = "brandId", value = "品牌Id")
    private Long brandId;

    @ApiModelProperty(name = "memberCode", value = "会员code")
    private String memberCode;

    @ApiModelProperty(name = "changeBills", value = "变更单据")
    private String changeBills;

    @ApiModelProperty(name = "cardNo", value = "会员卡号")
    private String cardNo;

    @ApiModelProperty(name = "offlineCardNo", value = "线下会员卡号")
    private String offlineCardNo;

    @ApiModelProperty(name = "changeIntegral", value = "调整积分数量")
    private Integer changeIntegral;

    @ApiModelProperty(value = "变更时间", name = "changeDate", example = "变更时间")
    private Date changeDate;

    @ApiModelProperty(name = "changeType", value = "调整类型")
    private String changeType;

    @ApiModelProperty(name = "businessType", value = "业务类型")
    private String businessType;

    @ApiModelProperty(name = "changeDetails", value = "积分调整详情")
    private String changeDetails;

    @ApiModelProperty(name = "operateUserId", value = "操作人id")
    private Long operateUserId;

    @ApiModelProperty(name = "operateUserName", value = "操作人姓名")
    private String operateUserName;

    @ApiModelProperty(name = "pointsAmount", value = "积分数额")
    private Integer pointsAmount;

    @ApiModelProperty(name = "storeId", value = "门店id")
    private String storeId;

    @ApiModelProperty(name = "source", value = "积分来源")
    private String source;

}

==> members-facade-2.0.0-20191022.125220-83-sources.jar: com/bizvane/members/facade/service/card/request/IntegralChangeRequestModel.java <==
package com.bizvane.members.facade.service.card.request;

import io.swagger.annotations.ApiModelProperty;
import lombok.*;

import java.util.Date;

/**
 * @Author: Hou Hong Bin
 * @CreateTime: 2018/8/17.
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode
public class IntegralChangeRequestModel {

    @ApiModelProperty(name = "sysCompanyId", value = "公司id")
    private Long sysCompanyId;

    @ApiModelProperty(name = "brandId", value = "品牌Id")
    private Long brandId;

    @ApiModelProperty(name = "memberCode", value = "会员code")
    private String memberCode;

    @ApiModelProperty(name = "changeBills", value = "变更单据")
    private String changeBills;

    @ApiModelProperty(name = "cardNo", value = "会员卡号")
    private String cardNo;

    @ApiModelProperty(name = "offlineCardNo", value = "线下会员卡号")
    private String offlineCardNo;

    @ApiModelProperty(name = "changeIntegral", value = "调整积分数量")
    private Integer changeIntegral;

    @ApiModelProperty(value = "变更时间", name = "changeDate", example = "变更时间")
    private Date changeDate;

    @ApiModelProperty(name = "changeType", value = "调整类型")
    private String changeType;

    @ApiModelProperty(name = "businessType", value = "业务类型")
    private String businessType;

    @ApiModelProperty(name = "changeDetails", value = "积分调整详情")
    private String changeDetails;

    @ApiModelProperty(name = "operateUserId", value = "操作人id")
    private Long operateUserId;

    @ApiModelProperty(name = "operateUserName", value = "操作人姓名")
    private String operateUserName;

    @ApiModelProperty(name = "pointsAmount", value = "积分数额")
    private Integer pointsAmount;

    @ApiModelProperty(name = "storeId", value = "门店id")
    private String storeId;

    @ApiModelProperty(name = "source", value = "积分来源")
    private String source;

}
